@@ -1,6 +1,7 @@
 
 #include <R.h>
 #include <Rdefines.h>
+#include <R_ext/Rdynload.h>
 
 #ifdef WIN32
 
@@ -209,3 +210,14 @@ SEXP r_ping(SEXP p_destination, SEXP p_port, SEXP p_type, SEXP p_continuous,
   UNPROTECT(1);
   return result;
 }
+
+static const R_CallMethodDef callMethods[]  = {
+  {"r_ping", (DL_FUNC) &r_ping, 7},
+  {NULL, NULL, 0}
+};
+
+void R_init_parsedate(DllInfo *dll) {
+  R_registerRoutines(dll, NULL, callMethods, NULL, NULL);
+  R_useDynamicSymbols(dll, FALSE);
+  R_forceSymbols(dll, TRUE);
+}
